#
# spec file for package python-xlwt
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without tests
Name:           python-xlwt
Version:        1.3.0
Release:        2.19
Summary:        Library to Create Spreadsheet Files Compatible With MS Excel 97/2000/XP/2003
License:        BSD-4-Clause AND BSD-3-Clause AND LGPL-2.1-or-later
Group:          Development/Languages/Python
URL:            https://secure.simplistix.co.uk/svn/xlwt/trunk
Source:         https://files.pythonhosted.org/packages/source/x/xlwt/xlwt-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildRequires:  python3-pkginfo
BuildArch:      noarch
%if %{with tests}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
xlwt is a library for generating spreadsheet files that are compatible
with Excel 97/2000/XP/2003, OpenOffice.org Calc, and Gnumeric. xlwt has
full support for Unicode. Excel spreadsheets can be generated on any
platform without needing Excel or a COM server. The only requirement is
Python 2.3 to 2.6. xlwt is a fork of pyExcelerator.

%prep
%setup -q -n xlwt-%{version}
# fix end of line encoding
sed -i 's/\r$//' examples/{numbers_demo.py,panes2.py,image_chg_col_wid.py,zoom_magnification.py}

%build
%python_build
cd docs && make html && rm _build/html/.buildinfo

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with tests}
%check
%pytest
%endif

%files %{python_files}
%doc README.rst
%doc docs/_build/html/
%doc examples/
%{python_sitelib}/*

%changelog
* Fri May 29 2020 Marketa Calabkova <mcalabkova@suse.com>
- Replace nose with pytest
* Tue Jan 30 2018 toddrme2178@gmail.com
- Update to version 1.3.0
  * Officially support Python 3.6, drop support for 2.6.
  * Fix bytes/string type mismatch in :func:`upack2rt` on python 3.
  * Packaging and code style tweaks.
  * Use generator expressions to avoid unnecessary lists in memory.
* Mon Apr 24 2017 toddrme2178@gmail.com
- update to version 1.2.0:
  * Remove "LOCALE" from regular expression that caused
    :class:`DeprecationWarning` that become an exception in Python 3.6
  * Add :meth:`Workbook.sheet_index` helper.
  * :meth:`Workbook.get_sheet` now takes either a string name or an
    integer index.
- update to version 1.1.2:
  * Fix failure in style compression under Python 3.
  * Officially support Python 3.5
  * Documentation tweaks.
- update to version 1.1.1:
  * Fix release problems.
- update to version 1.1.0:
  * Fix SST BIFF record in Python 3.
  * Fix for writing :class:`ExternSheetRecord` in Python 3.
  * Add the ability to insert bitmap images from buffers as well as
    files.
  * Official support for Python 3.5.
- Implement single-spec version
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 1.0.0:
  * Python 3 support.
  * Initial set of unit tests.
  * An initial set of Sphinx documentation.
  * Move to setuptools for packaging.
  * Wire up Travis, Coveralls and ReadTheDocs.
  * Allow longs as row indexes.
- add new dependencies python-Sphinx, python-nose, python-pkginfo,
  python-setuptools
- only define python_sitelib for SLE11 and remove %%py_requires
- fix end of line encoding of examples scripts
- remove CFLAGS declaration
- build the documentation with sphinx
- run the tests with nosetests
- update the paths of doc and examples: changed upstream
* Wed Sep 18 2013 idonmez@suse.com
- Update to version 0.7.5
  * No changelog provided upstream
* Thu Dec 27 2012 cfarrell@suse.com
- license update: BSD-4-Clause and BSD-3-Clause and LGPL-2.1+
  See licenses.py and xlwt/Util.py
* Fri Apr 27 2012 jfunk@funktronics.ca
- Update to 0.7.4
  * No change information available
* Tue Feb 21 2012 jfunk@funktronics.ca
- Update to 0.7.3
- Update spec for current conventions
* Wed May 12 2010 jfunk@funktronics.ca
- Initial release
